@@ -21,10 +21,7 @@ package org.apache.thrift;
 
 import org.apache.thrift.protocol.TProtocol;
 
-/**
- * Generic base interface for generated Thrift objects.
- *
- */
+/** Generic base interface for generated Thrift objects. */
 public interface TSerializable {
 
   /**
@@ -33,7 +30,7 @@ public interface TSerializable {
    * @param iprot Input protocol
    * @throws TException if there is an error reading from iprot
    */
-  public void read(TProtocol iprot) throws TException;
+  void read(TProtocol iprot) throws TException;
 
   /**
    * Writes the objects out to the protocol
@@ -41,6 +38,5 @@ public interface TSerializable {
    * @param oprot Output protocol
    * @throws TException if there is an error writing to oprot
    */
-  public void write(TProtocol oprot) throws TException;
-
+  void write(TProtocol oprot) throws TException;
 }
